@@ -1,4 +1,4 @@
-from pyrosm.config.default_tags import highway_tags_to_keep, amenity_tags_to_keep
+from pyrosm.config.default_tags import highway_tags_to_keep, building_tags_to_keep
 from pyrosm.config.osm_filters import get_osm_filter
 
 
@@ -11,8 +11,8 @@ class NetworkFilter:
 
 class Tags:
     networks = highway_tags_to_keep
-    amenities = amenity_tags_to_keep
-    buildings = ["TODO"]
+    buildings = building_tags_to_keep
+    amenities = building_tags_to_keep
 
 
 class Conf:
